@@ -1,5 +1,5 @@
 import unittest
-from src.ocr_product import OCRProduct
+# from src.ocr_product import OCRProduct
 
 
 class TestProduct(unittest.TestCase):
